package com.citra.pivot.demo;

import java.sql.Connection;
import java.sql.DriverManager;

import org.olap4j.OlapConnection;
import org.olap4j.OlapWrapper;

import com.citra.pivot.PivotTable;
import com.citra.pivot.olap.DefaultOlapProvider;
import com.citra.pivot.olap.OlapDefinition;
import com.citra.pivot.olap.OlapUtils;
import com.citra.pivot.olap.data.DataSource;
import com.citra.pivot.olap.data.DataSourceException;
import com.citra.pivot.olap4j.Olap4jDataSource;
/**
 * Pivot table demo for use with a Microsoft Analysis Server
 */
public class SSASDemo extends AbstractOlapDemo {
/**
 *
 */
public SSASDemo() {
	this(true);
}
/**
 *
 */
public SSASDemo(boolean useRemote) {
	super(useRemote);
}
/**
 *
 */
protected DataSource createDataSource() {
	try {
		DataSource ds = new Olap4jDataSource(getConnection());
		return ds;
	} catch (Exception e) {
		e.printStackTrace();
		return null;
	}
}
/**
 *
 */
protected void customizeTable(PivotTable pivotTable, DefaultOlapProvider provider) {
	//get pivot definition in order to modify it
	OlapDefinition def = provider.getOlapDefinition();
	//modify definition
	//pivot product on rows
	def.setHierarchy(OlapUtils.findHierarchyByName(def.getCube(), "Customer Geography"), OlapDefinition.ROW_TYPE);
	//pivot measures on columns
	def.setHierarchy(def.getMeasureHierarchy(), OlapDefinition.COLUMN_TYPE);

	//set new definition
	try {
		provider.setOlapDefinition(def);
	} catch (DataSourceException e) {
		e.printStackTrace();
	}
}
/**
 *
 */
public OlapConnection getConnection() throws Exception {
	return getSQLServerConnection();
}
/**
 *
 */
public static OlapConnection getSQLServerConnection() throws Exception {
	Class.forName("org.olap4j.driver.xmla.XmlaOlap4jDriver");
	Connection connection = (Connection) DriverManager.getConnection("jdbc:xmla:Server=http://localhost/olap/msmdpump.dll;");
	// + "Catalog=Adventure Works DW");
	OlapWrapper wrapper = (OlapWrapper) connection;
	OlapConnection olapConnection = (OlapConnection) wrapper.unwrap(OlapConnection.class);
	return olapConnection;
}
/**
 *
 */
public static void main(String[] args) {
	//run demo
	SSASDemo demo = new SSASDemo();
	try {
		//show
		demo.show();
	}
	catch (Exception e) {
		e.printStackTrace();
	}
}
}
